summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2020-12-01 23:44:10 +0100
committerRay <[email protected]>2020-12-01 23:44:10 +0100
commit60928ec82c28fae8ea98f5f29e260b24717123ff (patch)
tree10e54db780c6d944dbf185f8f453cd7bd87c1409 /src/raylib.h
parent0481053dad5f784a2aa5c25ab6d32145bbdaa4ff (diff)
downloadraylib-60928ec82c28fae8ea98f5f29e260b24717123ff.tar.gz
raylib-60928ec82c28fae8ea98f5f29e260b24717123ff.zip
ADDED: UnloadModelKeepMeshes() #1441
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 610c836d..2d635406 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -1321,7 +1321,8 @@ RLAPI void DrawGizmo(Vector3 position);
// Model loading/unloading functions
RLAPI Model LoadModel(const char *fileName); // Load model from files (meshes and materials)
RLAPI Model LoadModelFromMesh(Mesh mesh); // Load model from generated mesh (default material)
-RLAPI void UnloadModel(Model model); // Unload model from memory (RAM and/or VRAM)
+RLAPI void UnloadModel(Model model); // Unload model (including meshes) from memory (RAM and/or VRAM)
+RLAPI void UnloadModelKeepMeshes(Model model); // Unload model (but not meshes) from memory (RAM and/or VRAM)
// Mesh loading/unloading functions
RLAPI Mesh *LoadMeshes(const char *fileName, int *meshCount); // Load meshes from model file